"""
This type stub file was generated by pyright.
"""

from datetime import datetime

from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

class WorkerProduct(TaranisBaseModel):
    data: bytes | None = ...
    mime_type: str | None = ...

class Product(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _search_fields = ...
    _pretty_name = ...
    id: str | None = ...
    title: str
    description: str | None = ...
    created: datetime | None = ...
    auto_publish: bool | None = ...
    product_type_id: int
    report_items: list[str] = ...
    last_rendered: datetime | None = ...
    render_result: str | None = ...
    mime_type: str | None = ...
