"""
This type stub file was generated by pyright.
"""

from typing import Any

from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

class ProfileSettingsDashboard(TaranisBaseModel):
    show_trending_clusters: bool = ...
    show_charts: bool = ...
    trending_cluster_days: int = ...
    trending_cluster_filter: list[Any] = ...

class ProfileSettings(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    dark_theme: bool = ...
    compact_view: bool = ...
    show_charts: bool = ...
    infinite_scroll: bool = ...
    advanced_story_options: bool = ...
    language: str = ...
    hotkeys: dict[str, Any] = ...
    split_view: bool = ...
    end_of_shift: str | None = ...
    highlight: bool = ...
    dashboard: ProfileSettingsDashboard = ...

class UserProfile(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _search_fields = ...
    id: int | None = ...
    username: str = ...
    name: str
    organization: dict[str, Any] | None = ...
    profile: ProfileSettings = ...
    permissions: list[str] | None = ...
    roles: list[dict[str, Any]] | None = ...
