"""
This type stub file was generated by pyright.
"""

from datetime import datetime
from typing import ClassVar, Final

from models.admin import ReportItemAttribute
from models.assess import Story
from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

class ReportItemCpe(TaranisBaseModel):
    id: int | None = ...
    value: str

class ReportItemAttributeGroup(TaranisBaseModel):
    title: str
    attributes: list[ReportItemAttribute] = ...

class ReportItem(TaranisBaseModel):
    _core_endpoint: ClassVar[str] = ...
    _model_name: ClassVar[str] = ...
    _search_fields: Final[list[str]] = ...
    _pretty_name: ClassVar[str] = ...
    id: str | None = ...
    title: str | None = ...
    created: datetime | None = ...
    last_updated: datetime | None = ...
    completed: bool | None = ...
    user_id: int | None = ...
    report_item_type_id: int | None = ...
    report_item_type: str | None = ...
    stories: list[Story | str] | None = ...
    grouped_attributes: list[ReportItemAttributeGroup] | None = ...
    attributes: list[ReportItemAttribute] | dict[str, str] = ...
    report_item_cpes: list[ReportItemCpe] | None = ...
