"""
This type stub file was generated by pyright.
"""

from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

class Asset(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _search_fields = ...
    _pretty_name = ...
    id: int | None = ...
    name: str | None = ...
    description: str | None = ...
    serial: str | None = ...
    asset_group_id: str | None = ...
    asset_cpes: list[int] = ...
    vulnerabilities: list[int] = ...
    vulnerabilities_count: int | None = ...
